"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tempy_1 = __importDefault(require("tempy"));
const path_1 = __importDefault(require("path"));
const execa_1 = __importDefault(require("execa"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const _1 = __importDefault(require("."));
const get_install_cmd_1 = __importDefault(require("./get-install-cmd"));
describe('integration test', () => {
    let PKG_ROOT;
    let LIBRARY_NAME;
    let LIBRARY_ROOT;
    let INSTALL_CMD;
    describe('succesful create', () => {
        beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
            PKG_ROOT = tempy_1.default.directory();
            LIBRARY_NAME = 'my-cool-library';
            LIBRARY_ROOT = path_1.default.join(PKG_ROOT, LIBRARY_NAME);
            process.chdir(PKG_ROOT);
            INSTALL_CMD = (0, get_install_cmd_1.default)();
            yield (0, _1.default)(LIBRARY_NAME);
        }), 60000);
        it('replace the package.json name with the correct name', () => __awaiter(void 0, void 0, void 0, function* () {
            const pkgPath = path_1.default.join(LIBRARY_ROOT, 'package.json');
            expect(fs_extra_1.default.existsSync(pkgPath)).toBe(true);
            expect(require(pkgPath).name).toBe(LIBRARY_NAME);
        }));
        [
            { cmd: 'lint', asyncTimeout: 20000 },
            { cmd: 'test', asyncTimeout: 30000 },
            { cmd: 'build', asyncTimeout: 60000 },
        ].forEach(({ cmd, asyncTimeout = 10000, }) => {
            it(`scaffolds such that "${cmd}" command runs successfully`, () => __awaiter(void 0, void 0, void 0, function* () {
                yield expect((0, execa_1.default)(INSTALL_CMD, ['run', cmd], { cwd: LIBRARY_ROOT })).resolves.toBeDefined();
            }), asyncTimeout);
        });
    });
    describe('failure cases', () => {
        beforeEach(() => {
            PKG_ROOT = tempy_1.default.directory();
            LIBRARY_NAME = 'my-cool-library';
            LIBRARY_ROOT = path_1.default.join(PKG_ROOT, LIBRARY_NAME);
            process.chdir(PKG_ROOT);
            INSTALL_CMD = (0, get_install_cmd_1.default)();
        });
        it('fails when the library name is missing', () => __awaiter(void 0, void 0, void 0, function* () {
            yield expect((0, _1.default)()).rejects.toEqual(expect.any(Error));
        }));
        it('fails when a directory already exists', () => __awaiter(void 0, void 0, void 0, function* () {
            yield fs_extra_1.default.mkdir(path_1.default.join(PKG_ROOT, LIBRARY_NAME));
            yield expect((0, _1.default)()).rejects.toEqual(expect.any(Error));
        }));
    });
});
//# sourceMappingURL=integration.test.js.map