var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import path from 'path';
import fs from 'fs-extra';
import execa from 'execa';
import chalk from 'chalk';
import readPkgUp from 'read-pkg-up';
import * as messages from './messages';
import getInstallCmd from './get-install-cmd';
export default function createWebScriptsLibrary(projectName) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!projectName) {
            throw new Error(messages.missingProjectName());
        }
        if (fs.existsSync(projectName) && projectName !== '.') {
            throw new Error(messages.alreadyExists(projectName));
        }
        const { packageJson: cwslPkg } = readPkgUp.sync({
            cwd: __dirname,
        }) || {};
        const projectPath = path.resolve(process.cwd(), projectName);
        const templatePath = path.resolve(__dirname, '..', 'template');
        console.log(chalk.gray('Copying template...'));
        yield fs.copy(templatePath, projectPath);
        console.log(chalk.gray('Writing over necessary files...'));
        process.chdir(projectPath);
        const newPkgPath = path.join(projectPath, 'package.json');
        const newPkg = require(newPkgPath);
        newPkg.name = projectName;
        newPkg.devDependencies['@spotify/web-scripts'] =
            ((cwslPkg === null || cwslPkg === void 0 ? void 0 : cwslPkg.devDependencies) || {})['@spotify/web-scripts'] ||
                newPkg.devDependencies['@spotify/web-scripts'];
        yield fs.writeFile(newPkgPath, JSON.stringify(newPkg, null, 2));
        console.log(chalk.gray('Installing dependencies...'));
        process.chdir(projectPath);
        yield execa(getInstallCmd(), ['install']);
        console.log(messages.start(projectName));
    });
}
//# sourceMappingURL=index.js.map