var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import tempy from 'tempy';
import path from 'path';
import execa from 'execa';
import fs from 'fs-extra';
import createWebScriptsLibrary from '.';
import getInstallCmd from './get-install-cmd';
describe('integration test', () => {
    let PKG_ROOT;
    let LIBRARY_NAME;
    let LIBRARY_ROOT;
    let INSTALL_CMD;
    describe('succesful create', () => {
        beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
            PKG_ROOT = tempy.directory();
            LIBRARY_NAME = 'my-cool-library';
            LIBRARY_ROOT = path.join(PKG_ROOT, LIBRARY_NAME);
            process.chdir(PKG_ROOT);
            INSTALL_CMD = getInstallCmd();
            yield createWebScriptsLibrary(LIBRARY_NAME);
        }), 60000);
        it('replace the package.json name with the correct name', () => __awaiter(void 0, void 0, void 0, function* () {
            const pkgPath = path.join(LIBRARY_ROOT, 'package.json');
            expect(fs.existsSync(pkgPath)).toBe(true);
            expect(require(pkgPath).name).toBe(LIBRARY_NAME);
        }));
        [
            { cmd: 'lint', asyncTimeout: 20000 },
            { cmd: 'test', asyncTimeout: 30000 },
            { cmd: 'build', asyncTimeout: 60000 },
        ].forEach(({ cmd, asyncTimeout = 10000, }) => {
            it(`scaffolds such that "${cmd}" command runs successfully`, () => __awaiter(void 0, void 0, void 0, function* () {
                yield expect(execa(INSTALL_CMD, ['run', cmd], { cwd: LIBRARY_ROOT })).resolves.toBeDefined();
            }), asyncTimeout);
        });
    });
    describe('failure cases', () => {
        beforeEach(() => {
            PKG_ROOT = tempy.directory();
            LIBRARY_NAME = 'my-cool-library';
            LIBRARY_ROOT = path.join(PKG_ROOT, LIBRARY_NAME);
            process.chdir(PKG_ROOT);
            INSTALL_CMD = getInstallCmd();
        });
        it('fails when the library name is missing', () => __awaiter(void 0, void 0, void 0, function* () {
            yield expect(createWebScriptsLibrary()).rejects.toEqual(expect.any(Error));
        }));
        it('fails when a directory already exists', () => __awaiter(void 0, void 0, void 0, function* () {
            yield fs.mkdir(path.join(PKG_ROOT, LIBRARY_NAME));
            yield expect(createWebScriptsLibrary()).rejects.toEqual(expect.any(Error));
        }));
    });
});
//# sourceMappingURL=integration.test.js.map